use v6-alpha;

class DateTime::Recurrence-0.01;

has Recurrence $.set;

# TODO - datetime-specific methods:
#  add_duration, set_time_zone, ...


=kwid

= NAME

DateTime::Recurrence - An object representing a datetime recurrence set

= SYNOPSIS

  use DateTime::Recurrence;

  # XXX

= DESCRIPTION

This class represents an infinite recurrence of datetimes.

= CONSTRUCTORS

- `new( ... )`

  # XXX

= OBJECT METHODS

The following methods are available for Set::Span objects:

  # XXX - see Recurrence.pm

= AUTHOR

Flavio S. Glock, <fglock@pucrs.br>

= COPYRIGHT

Copyright (c) 2005, Flavio S. Glock.  All rights reserved.

This program is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
